==> boblogistics_0.16.15.zip: boblogistics_0.16.15/prototypes/item/logistic-container.lua <==
data.raw.item["logistic-chest-passive-provider"].order = "b[storage]-[logistic-chest-passive-provider-1]"
data.raw.item["logistic-chest-active-provider"].order = "b[storage]-[logistic-chest-active-provider-1]"
data.raw.item["logistic-chest-storage"].order = "b[storage]-[logistic-chest-storage-1]"
data.raw.item["logistic-chest-buffer"].order = "b[storage]-[logistic-chest-buffer-1]"
data.raw.item["logistic-chest-requester"].order = "b[storage]-[logistic-chest-requester-1]"


data:extend(
{
  {
    type = "item",
    name = "logistic-chest-passive-provider-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.2, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-passive-provider-2]",
    place_result = "logistic-chest-passive-provider-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-active-provider-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.7, g = 0.1, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-active-provider-2]",
    place_result = "logistic-chest-active-provider-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-storage-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.75, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-storage-2]",
    place_result = "logistic-chest-storage-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-buffer-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.2, g = 0.9, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-buffer-2]",
    place_result = "logistic-chest-buffer-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-requester-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.1, g = 0.4, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-requester-2]",
    place_result = "logistic-chest-requester-2",
    stack_size = 50
  }
}
)

data:extend(
{
  {
    type = "item",
    name = "logistic-chest-passive-provider-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.2, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-passive-provider-3]",
    place_result = "logistic-chest-passive-provider-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-active-provider-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.7, g = 0.1, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-active-provider-3]",
    place_result = "logistic-chest-active-provider-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-storage-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.75, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-storage-3]",
    place_result = "logistic-chest-storage-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-buffer-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.2, g = 0.9, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-buffer-3]",
    place_result = "logistic-chest-buffer-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-requester-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.1, g = 0.4, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-requester-3]",
    place_result = "logistic-chest-requester-3",
    stack_size = 50
  }
}
)

==> boblogistics_1.1.3.zip: boblogistics_1.1.3/prototypes/item/logistic-container.lua <==
data.raw.item["logistic-chest-passive-provider"].order = "b[storage]-[logistic-chest-passive-provider-1]"
data.raw.item["logistic-chest-active-provider"].order = "b[storage]-[logistic-chest-active-provider-1]"
data.raw.item["logistic-chest-storage"].order = "b[storage]-[logistic-chest-storage-1]"
data.raw.item["logistic-chest-buffer"].order = "b[storage]-[logistic-chest-buffer-1]"
data.raw.item["logistic-chest-requester"].order = "b[storage]-[logistic-chest-requester-1]"


data:extend(
{
  {
    type = "item",
    name = "logistic-chest-passive-provider-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.2, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-passive-provider-2]",
    place_result = "logistic-chest-passive-provider-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-active-provider-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.7, g = 0.1, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-active-provider-2]",
    place_result = "logistic-chest-active-provider-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-storage-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.75, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-storage-2]",
    place_result = "logistic-chest-storage-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-buffer-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.2, g = 0.9, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-buffer-2]",
    place_result = "logistic-chest-buffer-2",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-requester-2",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/brass-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.1, g = 0.4, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-2",
    order = "b[storage]-[logistic-chest-requester-2]",
    place_result = "logistic-chest-requester-2",
    stack_size = 50
  }
}
)

data:extend(
{
  {
    type = "item",
    name = "logistic-chest-passive-provider-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-logistic-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.2, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-passive-provider-3]",
    place_result = "logistic-chest-passive-provider-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-active-provider-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-logistic-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.7, g = 0.1, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-active-provider-3]",
    place_result = "logistic-chest-active-provider-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-storage-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-logistic-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.9, g = 0.75, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-storage-3]",
    place_result = "logistic-chest-storage-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-buffer-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-logistic-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.2, g = 0.9, b = 0.1, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-buffer-3]",
    place_result = "logistic-chest-buffer-3",
    stack_size = 50
  },
  {
    type = "item",
    name = "logistic-chest-requester-3",
    icons = {
      {
        icon = "__boblogistics__/graphics/icons/titanium-logistic-chest.png",
      },
      {
        icon = "__boblogistics__/graphics/icons/logistic-chest-port.png",
      },
      {
        icon = "__boblogistics__/graphics/entity/logistic-chest/logistic-chest-mask.png",
        tint = {r = 0.1, g = 0.4, b = 0.9, a = 1}
      }
    },
    icon_size = 32,
    subgroup = "logistic-chests-3",
    order = "b[storage]-[logistic-chest-requester-3]",
    place_result = "logistic-chest-requester-3",
    stack_size = 50
  }
}
)
